@@ -12,7 +12,7 @@ beforeAll() {
   export HERMIT_BIN_INSTALL_DIR=$PWD/userbin
 
   pushd ../packages
-  git init .
+  git init --template=/dev/null .
   git add .
   git config user.email "you@example.com"
   git config user.name "Your Name"
@@ -34,12 +34,26 @@ setupEnv() {
 
   ESCAPED_PWD=$(printf '%s\n' "$PWD" | sed -e 's/[\/&]/\\&/g')
   sed -i.bak "s/#PWD/${ESCAPED_PWD}/g" "${to}/bin/hermit.hcl"
+
+  (
+    cd ../testbins
+    tar cvzf testbin1.tar.gz testbin1
+    tar cvzf testbin2.tar.gz testbin2
+    tar cvzf testbin3.tar.gz testbin3
+
+    cd fake
+    tar cvzf ../faketestbin2.tar.gz testbin2
+  )
+  mv ../testbins/*.tar.gz "${to}/bin/"
+  tar -xf ../gitsource.tgz -C "${to}"
 }
 
 beforeEach() {
   setupEnv env testenv
   setupEnv oldenv testoldenv
   setupEnv env anotherenv
+  setupEnv env isolatedenv1
+  setupEnv env isolatedenv2
   mkdir -p ./userbin
 }
 
@@ -47,6 +61,8 @@ afterEach() {
   rm -rf ./testenv
   rm -rf ./testoldenv
   rm -rf ./anotherenv
+  rm -rf ./isolatedenv1
+  rm -rf ./isolatedenv2
   rm -rf ./userbin
 
   # some downloaded packages might not have write permission
